@@ -1,16 +1,32 @@
-package Clustericious::Client::Meta;
+=head1 NAME
 
+Clustericious::Client::Meta - simple meta object for constructing clients
+
+=head1 METHODS
+
+=over
+
+=cut
+
+package Clustericious::Client::Meta;
 use strict;
 use warnings;
 
-# ABSTRACT: simple meta object for constructing clients
-our $VERSION = '0.83_01'; # VERSION
-
 our %Routes; # hash from class name to array ref of routes.
 our %RouteAttributes; # hash from class name to hash ref of attributes.
 our %Objects; # hash from class name to array ref of objects.
 our @CommonRoutes = ( [ "version" => '' ], [ "status" => '' ], [ "api" => '' ], [ "logtail" => '' ] );
 
+=item add_route
+
+Add or replace documentation about a route.
+
+Parameters :
+    - the name of the client class
+    - the name of the route
+    - documentation about the route's arguments
+
+=cut
 
 sub add_route { # Keep track of routes that have are added.
     my $class      = shift;
@@ -25,6 +41,13 @@ sub add_route { # Keep track of routes that have are added.
     push @{ $Routes{$for} }, [ $route_name => $route_doc ];
 }
 
+=item get_route_doc
+
+Get documentation for a route.
+
+    $meta->get_route_doc($class,$route_name);
+
+=cut
 
 sub get_route_doc {
     my $class      = shift;
@@ -34,6 +57,24 @@ sub get_route_doc {
     return $found->[1];
 }
 
+=item add_route_attribute
+
+Add an attribute for a route.
+
+Parameters :
+
+    - the name of the attribute
+    - the value of the attribute.
+
+Recognized attributes :
+
+    - dont_read_files : if set, no attempt will be made to treat
+        arguments as yaml files.
+    - auto_failover : if set, when a connection fails and does not
+        return a status code, each url in the list of configured
+        failover_url's will be tried in turn.
+
+=cut
 
 sub add_route_attribute {
     my $class      = shift;
@@ -44,6 +85,11 @@ sub add_route_attribute {
     $RouteAttributes{$for}->{$route_name}{$attr_name} = $attr_value;
 }
 
+=item get_route_attribute
+
+Like the above but retrieve an attribute.
+
+=cut
 
 sub get_route_attribute {
     my $class      = shift;
@@ -53,6 +99,16 @@ sub get_route_attribute {
     return $RouteAttributes{$for}->{$route_name}{$attr_name};
 }
 
+=item add_object
+
+Add an object>
+
+Parameters :
+    - the name of the client class
+    - the name of the object
+    - documentation about the object.
+
+=cut
 
 sub add_object {
     my $class    = shift;
@@ -62,6 +118,15 @@ sub add_object {
     push @{ $Objects{$for} }, [ $obj_name => $obj_doc ];
 }
 
+=item routes, objects
+
+Return an array ref of routes/objects.
+
+Each element is a two element array; the
+first element is the name, the second is
+documentation.
+
+=cut
 
 sub routes {
     my $class = shift;
@@ -79,94 +144,3 @@ sub objects {
 1;
 
 
-
-
-__END__
-=pod
-
-=head1 NAME
-
-Clustericious::Client::Meta - simple meta object for constructing clients
-
-=head1 VERSION
-
-version 0.83_01
-
-=head1 METHODS
-
-=head2 add_route
-
-Add or replace documentation about a route.
-
-Parameters :
-    - the name of the client class
-    - the name of the route
-    - documentation about the route's arguments
-
-=head2 get_route_doc
-
-Get documentation for a route.
-
-    $meta->get_route_doc($class,$route_name);
-
-=head2 add_route_attribute
-
-Add an attribute for a route.
-
-Parameters :
-
-    - the name of the attribute
-    - the value of the attribute.
-
-Recognized attributes :
-
-    - dont_read_files : if set, no attempt will be made to treat
-        arguments as yaml files.
-    - auto_failover : if set, when a connection fails and does not
-        return a status code, each url in the list of configured
-        failover_url's will be tried in turn.
-
-=head2 get_route_attribute
-
-Like the above but retrieve an attribute.
-
-=head2 add_object
-
-Add an object>
-
-Parameters :
-    - the name of the client class
-    - the name of the object
-    - documentation about the object.
-
-=head2 routes, objects
-
-Return an array ref of routes/objects.
-
-Each element is a two element array; the
-first element is the name, the second is
-documentation.
-
-=head1 SEE ALSO
-
-L<Clustericious::Client>, L<Clustericious>
-
-=head1 AUTHOR
-
-original author: Curt Tilmes
-
-current maintainer: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Brian Duggan
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by NASA GSFC.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
